<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Undo</name>
    <message>
        <location filename="../UndoInit.js" line="+2"/>
        <source>&amp;Undo</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Cofnij</translatorcomment>
        <translation>&amp;Cofnij</translation>
    </message>
</context>
</TS>
